@@ -2,17 +2,9 @@ from datetime import date, datetime, timedelta, timezone
 from typing import Iterable, List, Optional
 
 from ..auth import Auth
-from ..models.ems import (
-    Facility,
-    MainService,
-    MetricValue,
-    ResourceType,
-    UtilityContract,
-    UtilitySpend,
-    UtilityUsage,
-)
+from ..models.ems import Facility, MainService, ResourceType, UtilityContract, UtilitySpend, UtilityUsage
 from .api import ApiEnvironment, ConfiguredApi
-from .pagination import PagedRecords, PageOptions
+from .pagination import PagedRecords
 
 
 class EmsService(ConfiguredApi):
@@ -31,29 +23,12 @@ class EmsService(ConfiguredApi):
         ),
     )
 
-    def __init__(self, auth: Auth, env: str = "production", **kwargs) -> None:
+    def __init__(self, auth: Auth, org_id: str, env: str = "production", **kwargs) -> None:
         super().__init__(env=env, auth=auth, **kwargs)
+        self.org_id = org_id
 
     def get_facility(self, id: int) -> Facility:
-        return Facility.from_api(self.get(f"facilities/{id}"))
-
-    def get_metric_values(
-        self,
-        asset_id: str,
-        metric_label: Optional[str] = None,
-        params: Optional[dict] = None,
-        page_options: Optional[PageOptions] = None,
-    ) -> Iterable[MetricValue]:
-        assert (
-            params is None
-            or sum([key not in ["effective_end_date", "effective_start_date"] for key in params]) == 0
-        ), f"Unrecognized query parameters: {params}"
-        resp = self.get(
-            "assets/metrics/values",
-            params={"asset_ids": asset_id, "metric_labels": metric_label, **(params or {})},
-        )
-        metric_values = resp[asset_id][metric_label]
-        return [MetricValue.from_api(value) for value in metric_values]
+        return Facility.from_api(self.get(f"{self.org_id}/facilities/{id}"))
 
     def get_main_services(
         self, facility_id: int, resource_type: Optional[ResourceType] = None
@@ -80,7 +55,7 @@ class EmsService(ConfiguredApi):
         Note `start_date` defaults to 10 years ago (the API's maximum limit) and
         `end_date` defaults to today."""
         resp = self.get(
-            f"facilities/{facility_id}/utility/spend/monthly",
+            f"{self.org_id}/facilities/{facility_id}/utility/spend/monthly",
             params={
                 "type": resource_type.value,
                 "date_start": start_date.strftime("%Y-%m"),
@@ -104,7 +79,7 @@ class EmsService(ConfiguredApi):
         Note `start_date` defaults to 10 years ago (the API's maximum limit) and
         `end_date` defaults to today."""
         resp = self.get(
-            f"facilities/{facility_id}/utility/usage/monthly",
+            f"{self.org_id}/facilities/{facility_id}/utility/usage/monthly",
             params={
                 "type": resource_type.value,
                 "date_start": start_date.strftime("%Y-%m"),
@@ -124,7 +99,7 @@ class EmsService(ConfiguredApi):
     ) -> UtilityUsage:
         """Get utility usage for facility `facility_id` and resource `resource_type`"""
         resp = self.get(
-            f"facilities/{facility_id}/usage/{interval}",
+            f"{self.org_id}/facilities/{facility_id}/usage/{interval}",
             params={
                 "type": resource_type.value,
                 "time_start": int(start.timestamp()),
@@ -135,5 +110,7 @@ class EmsService(ConfiguredApi):
 
     def get_utility_contracts_for_facility(self, facility_id: int) -> Iterable[UtilityContract]:
         return PagedRecords(
-            api=self, url=f"facilities/{facility_id}/contracts", record_parser=UtilityContract.from_api
+            api=self,
+            url=f"{self.org_id}/facilities/{facility_id}/contracts",
+            record_parser=UtilityContract.from_api,
         )
